@@ -3,9 +3,9 @@
 package Test::Regexp::Pattern;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2021-07-13'; # DATE
+our $DATE = '2022-07-24'; # DATE
 our $DIST = 'Test-Regexp-Pattern'; # DIST
-our $VERSION = '0.008'; # VERSION
+our $VERSION = '0.010'; # VERSION
 
 use 5.010001;
 use strict 'subs', 'vars';
@@ -54,7 +54,9 @@ sub _test_regexp_pattern {
             $Test->subtest(
                 "example #$i" .
                     ($eg->{name} ? " ($eg->{name})" :
-                     ($eg->{summary} ? " ($eg->{summary})" : "")),
+                     ($eg->{summary} ? " ($eg->{summary})" :
+                      (defined $eg->{str} ? " (str $eg->{str})" :
+                       ""))),
                 sub {
                     $Test->ok(defined($eg->{str}), 'example provides string to match') or do {
                         $ok = 0;
@@ -170,7 +172,7 @@ sub regexp_patterns_in_module_ok {
           L1:
             unless ($has_tests) {
                 $Test->ok(1);
-                $Test->diag("No regexp patterns to test");
+                $Test->diag("No regexp patterns to test in $modulepm");
             }
         } # subtest
     ) or $ok = 0;
@@ -277,7 +279,7 @@ Test::Regexp::Pattern - Test Regexp::Pattern patterns
 
 =head1 VERSION
 
-This document describes version 0.008 of Test::Regexp::Pattern (from Perl distribution Test-Regexp-Pattern), released on 2021-07-13.
+This document describes version 0.010 of Test::Regexp::Pattern (from Perl distribution Test-Regexp-Pattern), released on 2022-07-24.
 
 =head1 SYNOPSIS
 
@@ -341,14 +343,6 @@ Please visit the project's homepage at L<https://metacpan.org/release/Test-Regex
 
 Source repository is at L<https://github.com/perlancar/perl-Test-Regexp-Pattern>.
 
-=head1 BUGS
-
-Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Test-Regexp-Pattern>
-
-When submitting a bug or request, please include a test-file or a
-patch to an existing test-file that illustrates the bug or desired
-feature.
-
 =head1 SEE ALSO
 
 L<test-regexp-pattern>, a command-line interface for
@@ -362,11 +356,36 @@ L<Dist::Zilla::Plugin::Regexp::Pattern>
 
 perlancar <perlancar@cpan.org>
 
+=head1 CONTRIBUTING
+
+
+To contribute, you can send patches by email/via RT, or send pull requests on
+GitHub.
+
+Most of the time, you don't need to build the distribution yourself. You can
+simply modify the code, then test via:
+
+ % prove -l
+
+If you want to build the distribution (e.g. to try to install it locally on your
+system), you can install L<Dist::Zilla>,
+L<Dist::Zilla::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
+Dist::Zilla plugin and/or Pod::Weaver::Plugin. Any additional steps required
+beyond that are considered a bug and can be reported to me.
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2021, 2020, 2018 by perlancar@cpan.org.
+This software is copyright (c) 2022, 2020, 2018 by perlancar <perlancar@cpan.org>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Test-Regexp-Pattern>
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
+
 =cut
